.. role:: python(code)
    :language: python


==========
autotrello
==========

.. image:: https://img.shields.io/pypi/v/autotrello.svg
    :target: https://pypi.org/project/autotrello
    :alt: package version from PyPI

.. image:: https://img.shields.io/pypi/l/autotrello.svg
    :target: https://github.com/mbdevpl/autotrello/blob/master/NOTICE
    :alt: license

Automation of workflows and high-level access to Trello.

.. contents::
    :backlinks: none


Introduction
============

This package is in design phase. Contributions at design level are welcome.


Details
-------

To be decided.

.. code:: python

    import autotrello

Examples are available in `<examples.ipynb>`_.


Requirements
============

Python version 3.11 or later.

Python libraries as specified in `<requirements.txt>`_.
